@@ -23,6 +23,8 @@
 
 #include <set>
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace wd = Wikidata;
 
 enum {
@@ -84,7 +86,7 @@ public:
 
     QIODevice *out = nullptr;
     std::vector<LineInfo> lines;
-    WikidataQueryManager *m_wdMgr = new WikidataQueryManager(QCoreApplication::instance());
+    Wikidata::QueryManager *m_wdMgr = new Wikidata::QueryManager(QCoreApplication::instance());
     std::set<wd::Q> wdPartOfIds;
     std::map<wd::Q, wd::Item> wdItems;
     std::map<QString, wd::Image> wdImages;
@@ -238,11 +240,11 @@ void Generator::augmentFromWikidata()
     wdIds.erase(std::unique(wdIds.begin(), wdIds.end()), wdIds.end());
     qDebug() << "Retrieving" << wdIds.size() << "items from Wikidata";
 
-    auto query = new WikidataEntitiesQuery(m_wdMgr);
+    auto query = new Wikidata::EntitiesQuery(m_wdMgr);
     query->setItems(std::move(wdIds));
-    QObject::connect(query, &WikidataEntitiesQuery::partialResult, [this](auto query) { applyWikidataResults(std::move(query->takeResult())); });
-    QObject::connect(query, &WikidataQuery::finished, [this, query]() mutable {
-        if (query->error() != WikidataQuery::NoError) {
+    QObject::connect(query, &Wikidata::EntitiesQuery::partialResult, [this](auto query) { applyWikidataResults(std::move(query->takeResult())); });
+    QObject::connect(query, &Wikidata::Query::finished, [this, query]() mutable {
+        if (query->error() != Wikidata::Query::NoError) {
             qCritical() << "Wikidata query failed";
             QCoreApplication::exit(1);
             return;
@@ -271,6 +273,7 @@ static struct {
     { wd::Q(858485), LineInfo::LongDistance }, // high speed railway line
     { wd::Q(2138247), LineInfo::LocalTrain }, // Regional-Express
     { wd::Q(515449), LineInfo::LocalTrain }, // Regionalbahn
+    { wd::Q(1116067), LineInfo::RapidTransit }, // RER
 };
 
 static LineInfo::Mode modeFromWikidataType(wd::Q type)
@@ -310,6 +313,7 @@ static const wd::Q wd_product_types[] {
     wd::Q(2140646), // Stadtbahn
     wd::Q(1268865), // light rail
     wd::Q(113455515), // automated rapid transit
+    wd::Q(124130081), // commuter rail network
 };
 
 static bool isWikidataProductType(wd::Q type)
@@ -397,11 +401,11 @@ void Generator::augmentProductsFromWikidata()
     }
     qDebug() << "Retrieving" << wdIds.size() << "product items from Wikidata";
 
-    auto query = new WikidataEntitiesQuery(m_wdMgr);
+    auto query = new Wikidata::EntitiesQuery(m_wdMgr);
     query->setItems(std::move(wdIds));
-    QObject::connect(query, &WikidataEntitiesQuery::partialResult, [this](auto query) { applyWikidataProductResults(std::move(query->takeResult())); });
-    QObject::connect(query, &WikidataQuery::finished, [this, query]() mutable {
-        if (query->error() != WikidataQuery::NoError) {
+    QObject::connect(query, &Wikidata::EntitiesQuery::partialResult, [this](auto query) { applyWikidataProductResults(std::move(query->takeResult())); });
+    QObject::connect(query, &Wikidata::Query::finished, [this, query]() mutable {
+        if (query->error() != Wikidata::Query::NoError) {
             qCritical() << "Wikidata product query failed";
             QCoreApplication::exit(1);
             return;
@@ -484,11 +488,11 @@ void Generator::verifyImages()
     imageIds.erase(std::remove(imageIds.begin(), imageIds.end(), QString()), imageIds.end());
     qDebug() << "Verifying" << imageIds.size() << "images" << imageIds;
 
-    auto query = new WikidataImageMetadataQuery(m_wdMgr);
+    auto query = new Wikidata::ImageMetadataQuery(m_wdMgr);
     query->setImages(std::move(imageIds));
-    QObject::connect(query, &WikidataImageMetadataQuery::partialResult, [this](auto query) { verifyImageMetaData(std::move(query->takeResult())); });
-    QObject::connect(query, &WikidataQuery::finished, [this, query]() mutable {
-        if (query->error() != WikidataQuery::NoError) {
+    QObject::connect(query, &Wikidata::ImageMetadataQuery::partialResult, [this](auto query) { verifyImageMetaData(std::move(query->takeResult())); });
+    QObject::connect(query, &Wikidata::Query::finished, [this, query]() mutable {
+        if (query->error() != Wikidata::Query::NoError) {
             qCritical() << "Wikidata image metadata query failed";
             QCoreApplication::exit(1);
             return;
@@ -911,6 +915,7 @@ static inline constexpr uint16_t Bucket(uint16_t index) { return line_data_count
 int main(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
+    QCoreApplication::setApplicationName(u"KPublicTransport/KnowledgeDBGenerator"_s);
     QCommandLineParser parser;
     parser.addHelpOption();
     QCommandLineOption outFileOption({ QStringLiteral("o") }, QStringLiteral("Output file name"), QStringLiteral("out"));
@@ -936,6 +941,7 @@ int main(int argc, char **argv)
     reader->read(f.map(0, f.size()), f.size());
 
     Generator generator;
+    generator.m_wdMgr->setUserAgentEmailAddress(u"kde-pim@kde.org"_s);
     generator.out = &out;
     generator.processOSMData(std::move(dataSet));
 
