@@ -99,6 +99,7 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "BR", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "BT", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "BW", FeatureRemark, Feature::Restaurant, Feature::Available },
+    { "A", "BZ", FeatureRemark, Feature::BusinessArea, Feature::Available },
     { "A", "CK", IgnoreRemark, Feature::NoFeature, Feature::Unknown }, // Komfort Check-in advertisment
     { "A", "CR", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
     { "A", "EA", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
@@ -106,12 +107,17 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "EH", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "ER", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "EXTERNAL_ID", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
+    { "A", "FA", FeatureRemark, Feature::FamilyArea, Feature::Available },
     { "A", "FB", FeatureRemark, Feature::BikeStorage, Feature::Limited },
     { "A", "FH", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "FK", FeatureRemark, Feature::BikeStorage, Feature::Limited },
     { "A", "FR", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
-    { "A", "FS", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
+    // observied with different meanings - Conditional bike storage (DE) vs free wifi (CH)
+    // { "A", "FS", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
+    { "A", "FZ", FeatureRemark, Feature::FamilyArea, Feature::Available },
     { "A", "G ", FeatureRemark, Feature::BikeStorage, Feature::Limited },
+    // NASA: GTFS route type
+    { "A", "GT", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
     { "A", "HD", FeatureRemark, Feature::SilentArea, Feature::Available },
     { "A", "HK", FeatureRemark, Feature::ToddlerArea, Feature::Available },
     { "A", "JOURNEYNUMBER", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
@@ -123,7 +129,8 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "MN", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "MP", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "NAME", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
-    { "A", "NF", FeatureRemark, Feature::BikeStorage, Feature::Unavailable },
+    // observed with different meanings? no bike storage (DE?) vs. low floor vehicle (CH)
+    // { "A", "NF", FeatureRemark, Feature::BikeStorage, Feature::Unavailable },
     { "A", "OA", FeatureRemark, Feature::WheelchairAccessible, Feature::Conditional },
     { "A", "OC", FeatureRemark, Feature::WheelchairAccessibleToilet, Feature::Available },
     { "A", "OG", FeatureRemark, Feature::WheelchairAccessibleToilet, Feature::Limited },
@@ -131,7 +138,8 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "QP", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "RG", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "RO", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
-    { "A", "RZ", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    // observed with different meanings: wheelchair access in DE, quiet zone in CH
+    //{ "A", "RZ", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "SA", FeatureRemark, Feature::ToddlerArea, Feature::Limited },
     { "A", "SI", FeatureRemark, Feature::WheelchairAccessible, Feature::Limited },
     { "A", "SN", FeatureRemark, Feature::Restaurant, Feature::Available },
@@ -139,7 +147,11 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "TM", FeatureRemark, Feature::Restaurant, Feature::Limited },
     { "A", "TO", FeatureRemark, Feature::Toilet, Feature::Available },
     { "A", "UA", FeatureRemark, Feature::BusinessArea, Feature::Available },
+    { "A", "VB", FeatureRemark, Feature::BikeStorage, Feature::Limited },
+    { "A", "VN", FeatureRemark, Feature::BikeStorage, Feature::Unavailable },
+    { "A", "VR", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
     { "A", "WI", FeatureRemark, Feature::WiFi, Feature::Available },
+    { "A", "WR", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "WV", FeatureRemark, Feature::WiFi, Feature::Available },
     { "A", "ZB", FeatureRemark, Feature::WheelchairAccessible, Feature::Limited },
     { "A", "ZM", FeatureRemark, Feature::WheelchairAccessible, Feature::Limited },
@@ -153,6 +165,10 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "de", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "df", FeatureRemark, Feature::WheelchairAccessible, Feature::Unavailable },
     { "A", "dg", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    // NASA: literally just a '.'
+    { "A", "dj", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
+    { "A", "dk", FeatureRemark, Feature::Restaurant, Feature::Available },
+    { "A", "dl", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "ei", FeatureRemark, Feature::BikeStorage, Feature::Available },
     { "A", "ek", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "ga", FeatureRemark, Feature::Restaurant, Feature::Available },
@@ -179,6 +195,8 @@ static constexpr const RemarkData remarks_map[] = {
     // SBB line number?
     { "I", "FD", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
     { "I", "JF", TrainFormationRemark, Feature::NoFeature, Feature::Unknown },
+    // Swiss journey id
+    { "I", "JY", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
      // SBB: some unknown number for buses
     { "I", "RN", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
     { "I", "TC", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
@@ -188,6 +206,8 @@ static constexpr const RemarkData remarks_map[] = {
     { "I", "XP", PlatformSectorsRemark, Feature::NoFeature, Feature::Unknown },
     // SBB: some XML structure of unknown content, related to train/platform layouts
     { "I", "XT", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
+    // Swiss journey id
+    { "I", "sj", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
 };
 
 static std::vector<Message> parseRemarks(const QJsonArray &remL)
